#include "spilcd.h"

/*
 * Draw one pixel on the currently active display.
 * The color intensity scale for a normal pixel is from 0 to 255.
 * The color intensity scale for the reduced pixel is from 0 to 15.
 *
 * Parameters:
 *   x - The X parameter of the pixel.
 *   y - The Y parameter of the pixel.
 *   r - The intensity of the red color.
 *   g - The intensity of the green color.
 *   b - The intensity of the blue color.
 *
 * Return: void
 */
void lcd_drawPixel(lcd_t* lcd, uint8 x, uint8 y, uint8 r, uint8 g, uint8 b);

/*
 * Draw a filled rectangle on the currently active display.
 * The color intensity scale for a normal pixel is from 0 to 255.
 * The color intensity scale for the reduced pixel is from 0 to 15.
 *
 * Parameters:
 *   x - Parameter X of the upper left corner of the rectangle.
 *   y - Parameter Y of the upper left corner of the rectangle.
 *   w - The width of the rectangle.
 *   h - The height of the rectangle.
 *   r - The intensity of the red color.
 *   g - The intensity of the green color.
 *   b - The intensity of the blue color.
 *
 * Return: void
 */
void lcd_fillRect(lcd_t* lcd, uint8 x, uint8 y, uint8 w, uint8 h, uint8 r, uint8 g, uint8 b);

/*
 * Fill the entire screen with one color of the currently active display.
 * The color intensity scale for a normal pixel is from 0 to 255.
 * The color intensity scale for the reduced pixel is from 0 to 15.
 *
 * Parameters:
 *   r - The intensity of the red color.
 *   g - The intensity of the green color.
 *   b - The intensity of the blue color.
 *
 * Return: void
 */
void lcd_fillScreen(lcd_t* lcd, uint8 r, uint8 g, uint8 b);

